@@ -2,7 +2,7 @@
 
 import platform
 from pathlib import Path
-from typing import Dict
+from typing import Dict, List
 
 import pluggy
 import pytest
@@ -29,6 +29,11 @@ class FakeHook:
         """Create the virtual environment for testing."""
         pass
 
+    @hookimpl
+    def run_update(self, basedir: str, envname: str, upgrade: List):
+        """Update packages from upgrade list."""
+        pass
+
 
 @pytest.fixture
 def plugin_manager():
